Index: /anuga_work/production/onslow_2009_june/Arc_asc2raster_GDA94z50.py
===================================================================
--- /anuga_work/production/onslow_2009_june/Arc_asc2raster_GDA94z50.py	(revision 7260)
+++ /anuga_work/production/onslow_2009_june/Arc_asc2raster_GDA94z50.py	(revision 7261)
@@ -40,6 +40,6 @@
 ##    ocean = scenario_dir + "map_work\\\port_hedland.gdb\\outlines\\initial_conditions_ocean"
 
-    print 'Process: Create File GDB'
-    gp.CreateFileGDB_management(folder, "raster")
+##    print 'Process: Create File GDB'
+##    gp.CreateFileGDB_management(folder, "raster")
 
     gp.Workspace = raster_gbd
@@ -48,5 +48,5 @@
     
     #replication dictionary
-    replicate = (('onslow', ''),('_', ''),('max','_M'),
+    replicate = (('onslow', 'o'),('_', ''),('max','_M'),
                  ('CBD', 'CDB'),('All',''),
                  ('depth','_depth'),('speed', '_speed'),
@@ -54,5 +54,5 @@
 
     generate_filename = []
-    input_ascii = glob.glob(folder + '*elevation.asc')
+    input_ascii = glob.glob(folder + '*w_O*.asc')
 
     for infile in input_ascii:
Index: /anuga_work/production/onslow_2009_june/export_results.py
===================================================================
--- /anuga_work/production/onslow_2009_june/export_results.py	(revision 7260)
+++ /anuga_work/production/onslow_2009_june/export_results.py	(revision 7261)
@@ -22,5 +22,5 @@
 directory = project.output_folder
 
-time_dir1 = '20090616_154908_run_final_0.0_27283_mhingee'
+##time_dir1 = '20090616_154908_run_final_0.0_27283_mhingee'
 time_dir2 = '20090617_110255_run_final_0.0_27283_mhingee'
 ##time_dir3 = ''
@@ -32,6 +32,6 @@
   
 
-cellsize = 250
-##cellsize = 5
+##cellsize = 250
+cellsize = 20
 
 #timestep = None    # None means no timestep!
@@ -42,6 +42,6 @@
 ######
 
-#area = ['Bunbury', 'Busselton']  # strings must match keys in var_equations below
-area = ['All']      # 'All' means no special areas - the whole thing
+area = ['Onslow']  # strings must match keys in var_equations below
+##area = ['All']      # 'All' means no special areas - the whole thing
 
 ######
@@ -56,5 +56,5 @@
 
 # one or more key strings from var_equations above
-var = ['elevation']
+var = ['elevation','stage']
 
 ######
Index: /anuga_work/production/pt_hedland_2009/Arc_asc2raster_GDA94z50.py
===================================================================
--- /anuga_work/production/pt_hedland_2009/Arc_asc2raster_GDA94z50.py	(revision 7260)
+++ /anuga_work/production/pt_hedland_2009/Arc_asc2raster_GDA94z50.py	(revision 7261)
@@ -40,6 +40,6 @@
 ##    ocean = scenario_dir + "map_work\\\port_hedland.gdb\\outlines\\initial_conditions_ocean"
 
-    print 'Process: Create File GDB'
-    gp.CreateFileGDB_management(folder, "raster")
+##    print 'Process: Create File GDB'
+##    gp.CreateFileGDB_management(folder, "raster")
 
     gp.Workspace = raster_gbd
@@ -54,5 +54,5 @@
 
     generate_filename = []
-    input_ascii = glob.glob(folder + '*elevation.asc')
+    input_ascii = glob.glob(folder + '*Town*.asc')
 
     for infile in input_ascii:
Index: /anuga_work/production/pt_hedland_2009/export_results.py
===================================================================
--- /anuga_work/production/pt_hedland_2009/export_results.py	(revision 7260)
+++ /anuga_work/production/pt_hedland_2009/export_results.py	(revision 7261)
@@ -32,6 +32,6 @@
   
 
-cellsize = 250
-##cellsize = 5
+##cellsize = 250
+cellsize = 20
 
 #timestep = None    # None means no timestep!
@@ -42,6 +42,6 @@
 ######
 
-#area = ['Bunbury', 'Busselton']  # strings must match keys in var_equations below
-area = ['All']      # 'All' means no special areas - the whole thing
+area = ['Town']  # strings must match keys in var_equations below
+##area = ['All']      # 'All' means no special areas - the whole thing
 
 ######
@@ -56,5 +56,5 @@
 
 # one or more key strings from var_equations above
-var = ['elevation']
+var = ['elevation','stage']
 
 ######
Index: /anuga_work/production/pt_hedland_2009/project.py
===================================================================
--- /anuga_work/production/pt_hedland_2009/project.py	(revision 7260)
+++ /anuga_work/production/pt_hedland_2009/project.py	(revision 7261)
@@ -126,9 +126,9 @@
 #-------------------------------------------------------------------------------
 
-# ASCII export grid for Bruny
-##xminBruny = 523900
-##xmaxBruny = 533200
-##yminBruny = 5204300
-##ymaxBruny = 5213100
+# ASCII export grid for Pt Hedland
+xminTown = 659643
+xmaxTown = 676236
+yminTown = 7744216
+ymaxTown = 7757347
 
 

Index: /anuga_work/production/exmouth_2009/project.py
===================================================================
--- /anuga_work/production/exmouth_2009/project.py	(revision 7260)
+++ /anuga_work/production/exmouth_2009/project.py	(revision 7261)
@@ -35,5 +35,5 @@
 finaltime=1000         # final time for simulation
 
-setup = 'trial'         # This can be one of three values
+setup = 'final'         # This can be one of three values
                         #    trial - coarsest mesh, fast
                         #    basic - coarse mesh
@@ -143,9 +143,9 @@
 #-------------------------------------------------------------------------------
 
-# ASCII export grid for Bruny
-##xminBruny = 523900
-##xmaxBruny = 533200
-##yminBruny = 5204300
-##ymaxBruny = 5213100
+# ASCII export grid for Exmouth
+xminExmouth = 511616
+xmaxExmouth = 516764
+yminExmouth = 7568731
+ymaxExmouth = 7577540
 
 
Index: /anuga_work/production/onslow_2009_june/project.py
===================================================================
--- /anuga_work/production/onslow_2009_june/project.py	(revision 7260)
+++ /anuga_work/production/onslow_2009_june/project.py	(revision 7261)
@@ -139,9 +139,9 @@
 #-------------------------------------------------------------------------------
 
-# ASCII export grid for Bruny
-##xminBruny = 523900
-##xmaxBruny = 533200
-##yminBruny = 5204300
-##ymaxBruny = 5213100
+# ASCII export grid for Onslow
+xminOnslow = 301199
+xmaxOnslow = 311353
+yminOnslow = 7600921
+ymaxOnslow = 7609833
 
 